parse

Function parse 

pub fn parse<'src>(text: &'src str) -> PhpDoc<'src>
Parse a raw doc-comment string into a PhpDoc.

The input should be the full comment text including /** and */ delimiters. If the delimiters are missing, the text is parsed as-is.